@@ -21,10 +21,9 @@ class DistributorManager:
         # Be careful when changing the init order of these channels
         self.userscript_req_channel = ServerDistributorMangerUserScriptRequestChannel(
             context=self.context,
-            logger_level=log_level
+            logger_log_level=log_level
         )
-        print("Hello")
         self.distributor_req_channel = ServerDistributorManagerDistributorRequestChannel(
             context=self.context,
-            log_level=log_level
+            logger_log_level=log_level
         )
\ No newline at end of file
