@@ -34,8 +34,11 @@ class ServerDistributorMangerUserScriptRequestChannel(DistributorMangerUserScrip
     def run_worker(self):
         self.logger.info(f"DistributorManager's channel {self.__class__.__name__} is up and running at {self.channel_address}")
         while True:
-            raw_msg = self.socket.recv_json()
-            self.logger.debug(raw_msg)
+            raw_obj = self.socket.recv_json()
+            self.socket.send_json({
+                "you_send_return": raw_obj 
+            })
+            self.logger.debug(raw_obj)
 
 
 class DistributorRequestChannel(ZMQReqRepServer):
